@@ -210,19 +210,20 @@ class IDBC:
                 msg_bit_list = []
                 try:
                     for f_sig in f_msg.signal_list:
-                        f_sig_value_range = list(range(f_sig.start_bit, f_sig.start_bit + f_sig.length_bit + 1))
+                        f_sig_value_range = list(range(f_sig.start_bit, f_sig.start_bit + f_sig.length_bit))
                         for one_value in f_sig_value_range:
                             if one_value in msg_bit_list:
-                                raise ValueError(f"{f_sig.msg_name} 位信息定义错误，请核对")
+                                print(f"{f_sig.real_signal_name} - [{f_sig.can_name}][{f_sig.msg_name}] 位信息定义错误，请核对")
+                                raise ValueError()
                         msg_bit_list += f_sig_value_range
                 except ValueError:
                     pass
 
 
-
 if __name__ == "__main__":
-    DBC_file = r'XXXX'
+    DBC_file = r"D:\canoe_project\canoe_project\tbox_project\vehicle_data\A18Y\dbc"
     dbc_obj = IDBC(DBC_file)
     dbc_obj.get_dbc_src_obj()
+    dbc_obj.judge_message_bit_is_not_conflict()
 
     print('')
